BaseChangeDetector
==========================================================

.. currentmodule:: skchange.change_detectors

.. autoclass:: BaseChangeDetector

.. include:: skchange.change_detectors.BaseChangeDetector.examples

.. raw:: html

    <div class="clearer"></div>